@@ -1,19 +1,16 @@
 #!/usr/bin/python3
 from gi.repository import Gtk
-import gettext
-_ = gettext.gettext
 
 class TopWindow(Gtk.Window):
 
     def __init__(self):
-        gettext.textdomain('debhello')
         Gtk.Window.__init__(self)
-        self.title = _("Hello World!")
+        self.title = "Hello World!"
         self.counter = 0
         self.border_width = 10
         self.set_default_size(400, 100)
         self.set_position(Gtk.WindowPosition.CENTER)
-        self.button = Gtk.Button(label=_("Click me!"))
+        self.button = Gtk.Button(label="Click me!")
         self.button.connect("clicked", self.on_button_clicked)
         self.add(self.button)
         self.connect("delete-event", self.on_window_destroy)
@@ -23,7 +20,7 @@ class TopWindow(Gtk.Window):
 
     def on_button_clicked(self, widget):
         self.counter += 1
-        widget.set_label(_("Hello, World!\nClick count = %i") % self.counter)
+        widget.set_label("Hello, World!\nClick count = %i" % self.counter)
 
 def main():
     window = TopWindow()
